import re
from datetime import date
from types import SimpleNamespace
from typing import Optional, TypedDict
from .util import validate_regexp
from .constant import Gender


class ParseResult(TypedDict):
    """The parse result of NIK"""
    gender: Gender
    """Gender, possible value: male and female"""
    yy: str
    """year of birth"""
    mm: str
    """month of birth"""
    dd: str
    """day of birth"""
    district: str
    """registration district"""


class NIK:
    """
    Indonesia ID number format
    NIK (Nomor Induk Kependudukan)
    https://en.wikipedia.org/wiki/National_identification_number#Indonesia
    https://www.npmjs.com/package/nik-validator?activeTab=explore
    """
    METADATA = SimpleNamespace(**{
        'iso3166_alpha2': 'IDN',
        'min_length': 16,
        'max_length': 16,
        'parsable': True,
        'checksum': False,
        'regexp': re.compile(r'^(?P<district>\d{6})'
                             r'(?P<dd>[0-7]\d)'
                             r'(?P<mm>(0[1-9]|1[012]))'
                             r'(?P<yy>\d{2})'
                             r'(?!0000)\d{4}$')
    })

    @staticmethod
    def validate(id_number: str) -> bool:
        """
        Validate the IDN id number
        """
        if not validate_regexp(id_number, NationalID.METADATA.regexp):
            return False
        if not NationalID.parse(id_number):
            return False
        return True

    @staticmethod
    def parse(id_number: str) -> Optional[ParseResult]:
        """parse the id number to the result"""
        match_obj = NationalID.METADATA.regexp.match(id_number)
        if not match_obj:
            return None

        district = match_obj.group("district")
        if district not in NIK.DISTRICT:
            return None

        gender = Gender.FEMALE if int(match_obj.group('dd')[0]) <= 3 else Gender.MALE
        yy = match_obj.group('yy')
        mm = match_obj.group('mm')
        dd = match_obj.group('dd') if gender == Gender.FEMALE else int(match_obj.group('dd')) - 30

        # Validate the date
        try:
            date(int(f'20{yy}'), int(mm), int(dd))
            date(int(f'19{yy}'), int(mm), int(dd))
        except ValueError:
            return None

        return {
            "gender": gender,
            'yy': yy,
            'mm': mm,
            'dd': str(dd),
            "district": district,
        }

    DISTRICT = ["110101", "110102", "110103", "110104", "110105", "110106", "110107", "110108", "110109", "110110",
                "110111", "110112", "110113", "110114", "110115", "110116", "110117", "110118", "110201", "110202",
                "110203", "110204", "110205", "110206", "110207", "110208", "110209", "110210", "110211", "110212",
                "110213", "110214", "110215", "110216", "110301", "110302", "110303", "110304", "110305", "110306",
                "110307", "110308", "110309", "110310", "110311", "110312", "110313", "110314", "110315", "110316",
                "110317", "110318", "110319", "110320", "110321", "110322", "110323", "110324", "110401", "110402",
                "110403", "110407", "110408", "110410", "110411", "110412", "110413", "110417", "110418", "110419",
                "110420", "110421", "110501", "110502", "110503", "110504", "110505", "110506", "110507", "110508",
                "110509", "110510", "110511", "110512", "110601", "110602", "110603", "110604", "110605", "110606",
                "110607", "110608", "110609", "110610", "110611", "110612", "110613", "110614", "110615", "110616",
                "110617", "110618", "110619", "110620", "110621", "110622", "110623", "110703", "110704", "110705",
                "110706", "110707", "110708", "110709", "110711", "110712", "110713", "110714", "110715", "110716",
                "110717", "110718", "110719", "110721", "110722", "110724", "110725", "110727", "110729", "110731",
                "110801", "110802", "110803", "110804", "110805", "110806", "110807", "110808", "110809", "110810",
                "110811", "110812", "110813", "110814", "110815", "110816", "110817", "110818", "110819", "110820",
                "110821", "110822", "110823", "110824", "110825", "110826", "110827", "110901", "110902", "110903",
                "110904", "110905", "110906", "110907", "110908", "110909", "110910", "111001", "111002", "111004",
                "111006", "111009", "111010", "111011", "111012", "111013", "111014", "111016", "111101", "111102",
                "111103", "111104", "111105", "111106", "111107", "111108", "111109", "111110", "111111", "111112",
                "111113", "111114", "111115", "111116", "111117", "111201", "111202", "111203", "111204", "111205",
                "111206", "111207", "111208", "111209", "111301", "111302", "111303", "111304", "111305", "111306",
                "111307", "111308", "111309", "111310", "111311", "111401", "111402", "111403", "111404", "111405",
                "111406", "111407", "111408", "111409", "111501", "111502", "111503", "111504", "111505", "111506",
                "111507", "111508", "111509", "111510", "111601", "111602", "111603", "111604", "111605", "111606",
                "111607", "111608", "111609", "111610", "111611", "111612", "111701", "111702", "111703", "111704",
                "111705", "111706", "111707", "111708", "111709", "111710", "111801", "111802", "111803", "111804",
                "111805", "111806", "111807", "111808", "117101", "117102", "117103", "117104", "117105", "117106",
                "117107", "117108", "117109", "117201", "117202", "117301", "117302", "117303", "117304", "117401",
                "117402", "117403", "117404", "117405", "117501", "117502", "117503", "117504", "117505", "120101",
                "120102", "120103", "120104", "120105", "120106", "120107", "120108", "120109", "120110", "120111",
                "120112", "120113", "120114", "120115", "120116", "120117", "120118", "120119", "120120", "120201",
                "120202", "120203", "120204", "120205", "120206", "120207", "120208", "120209", "120210", "120211",
                "120212", "120213", "120214", "120215", "120301", "120302", "120303", "120304", "120305", "120306",
                "120307", "120314", "120320", "120321", "120322", "120329", "120330", "120331", "120405", "120406",
                "120410", "120411", "120420", "120421", "120427", "120428", "120429", "120435", "120501", "120502",
                "120503", "120504", "120505", "120506", "120507", "120508", "120509", "120510", "120511", "120512",
                "120513", "120514", "120515", "120516", "120517", "120518", "120519", "120520", "120521", "120522",
                "120523", "120601", "120602", "120603", "120604", "120605", "120606", "120607", "120608", "120609",
                "120610", "120611", "120612", "120613", "120614", "120615", "120616", "120617", "120701", "120702",
                "120703", "120704", "120705", "120706", "120707", "120708", "120709", "120719", "120720", "120721",
                "120722", "120723", "120724", "120725", "120726", "120727", "120728", "120731", "120732", "120733",
                "120801", "120802", "120803", "120804", "120805", "120806", "120807", "120808", "120809", "120810",
                "120811", "120812", "120813", "120814", "120815", "120816", "120817", "120818", "120819", "120820",
                "120821", "120822", "120823", "120824", "120825", "120826", "120827", "120828", "120829", "120830",
                "120831", "120908", "120909", "120910", "120911", "120912", "120913", "120914", "120915", "120916",
                "120917", "120918", "120919", "120920", "120921", "120922", "120923", "120924", "120925", "120926",
                "120927", "120928", "120929", "120930", "120931", "120932", "121001", "121002", "121007", "121008",
                "121009", "121014", "121018", "121019", "121020", "121101", "121102", "121103", "121104", "121105",
                "121106", "121107", "121108", "121109", "121110", "121111", "121112", "121113", "121114", "121115",
                "121201", "121202", "121203", "121204", "121205", "121206", "121207", "121208", "121209", "121210",
                "121219", "121220", "121221", "121222", "121223", "121224", "121301", "121302", "121303", "121304",
                "121305", "121306", "121307", "121308", "121309", "121310", "121311", "121312", "121313", "121314",
                "121315", "121316", "121317", "121318", "121319", "121320", "121321", "121322", "121323", "121401",
                "121402", "121403", "121404", "121405", "121406", "121407", "121408", "121409", "121410", "121411",
                "121412", "121413", "121414", "121415", "121416", "121417", "121418", "121419", "121420", "121421",
                "121422", "121423", "121425", "121426", "121427", "121428", "121429", "121430", "121501", "121502",
                "121503", "121504", "121505", "121506", "121507", "121508", "121601", "121602", "121603", "121604",
                "121605", "121606", "121607", "121608", "121609", "121610", "121701", "121702", "121703", "121704",
                "121705", "121706", "121707", "121708", "121709", "121801", "121802", "121803", "121804", "121805",
                "121806", "121807", "121808", "121809", "121810", "121811", "121812", "121813", "121814", "121815",
                "121816", "121817", "121901", "121902", "121903", "121904", "121905", "121906", "121907", "122001",
                "122002", "122003", "122004", "122005", "122006", "122007", "122008", "122009", "122101", "122102",
                "122103", "122104", "122105", "122106", "122107", "122108", "122109", "122110", "122111", "122112",
                "122201", "122202", "122203", "122204", "122205", "122301", "122302", "122303", "122304", "122305",
                "122306", "122307", "122308", "122401", "122402", "122403", "122404", "122405", "122406", "122407",
                "122408", "122409", "122410", "122411", "122501", "122502", "122503", "122504", "122505", "122506",
                "122507", "122508", "127101", "127102", "127103", "127104", "127105", "127106", "127107", "127108",
                "127109", "127110", "127111", "127112", "127113", "127114", "127115", "127116", "127117", "127118",
                "127119", "127120", "127121", "127201", "127202", "127203", "127204", "127205", "127206", "127207",
                "127208", "127301", "127302", "127303", "127304", "127401", "127402", "127403", "127404", "127405",
                "127406", "127501", "127502", "127503", "127504", "127505", "127601", "127602", "127603", "127604",
                "127605", "127701", "127702", "127703", "127704", "127705", "127706", "130101", "130102", "130103",
                "130104", "130105", "130106", "130107", "130108", "130109", "130111", "130112", "130113", "130114",
                "130115", "130203", "130204", "130205", "130206", "130207", "130208", "130209", "130210", "130211",
                "130212", "130213", "130217", "130218", "130219", "130303", "130304", "130305", "130306", "130307",
                "130308", "130309", "130310", "130401", "130402", "130403", "130404", "130405", "130406", "130407",
                "130408", "130409", "130410", "130411", "130412", "130413", "130414", "130501", "130502", "130503",
                "130505", "130506", "130507", "130508", "130509", "130510", "130511", "130512", "130513", "130514",
                "130516", "130517", "130601", "130602", "130603", "130604", "130605", "130606", "130607", "130608",
                "130609", "130610", "130611", "130612", "130613", "130614", "130615", "130616", "130701", "130702",
                "130703", "130704", "130705", "130706", "130707", "130708", "130709", "130710", "130711", "130712",
                "130713", "130804", "130805", "130807", "130808", "130812", "130813", "130814", "130815", "130816",
                "130817", "130818", "130819", "130901", "130902", "130903", "130904", "130905", "130906", "130907",
                "130908", "130909", "130910", "131001", "131002", "131003", "131004", "131005", "131006", "131007",
                "131008", "131009", "131010", "131011", "131101", "131102", "131103", "131104", "131105", "131106",
                "131107", "131201", "131202", "131203", "131204", "131205", "131206", "131207", "131208", "131209",
                "131210", "131211", "137101", "137102", "137103", "137104", "137105", "137106", "137107", "137108",
                "137109", "137110", "137111", "137201", "137202", "137301", "137302", "137303", "137304", "137401",
                "137402", "137501", "137502", "137503", "137601", "137602", "137603", "137604", "137605", "137701",
                "137702", "137703", "137704", "140101", "140102", "140103", "140104", "140106", "140107", "140108",
                "140109", "140110", "140111", "140112", "140113", "140114", "140116", "140117", "140118", "140119",
                "140120", "140121", "140201", "140202", "140203", "140204", "140205", "140206", "140207", "140208",
                "140209", "140210", "140211", "140212", "140213", "140214", "140301", "140302", "140303", "140309",
                "140310", "140311", "140312", "140313", "140401", "140402", "140403", "140404", "140405", "140406",
                "140407", "140408", "140409", "140410", "140411", "140412", "140413", "140414", "140415", "140416",
                "140417", "140418", "140419", "140420", "140501", "140502", "140503", "140504", "140505", "140506",
                "140507", "140508", "140509", "140510", "140511", "140512", "140601", "140602", "140603", "140604",
                "140605", "140606", "140607", "140608", "140609", "140610", "140611", "140612", "140613", "140614",
                "140615", "140616", "140701", "140702", "140703", "140704", "140705", "140706", "140707", "140708",
                "140709", "140710", "140711", "140712", "140713", "140714", "140715", "140801", "140802", "140803",
                "140804", "140805", "140806", "140807", "140808", "140809", "140810", "140811", "140812", "140813",
                "140814", "140901", "140902", "140903", "140904", "140905", "140906", "140907", "140908", "140909",
                "140910", "140911", "140912", "140913", "140914", "140915", "141001", "141002", "141003", "141004",
                "141005", "141006", "141007", "141008", "147101", "147102", "147103", "147104", "147105", "147106",
                "147107", "147108", "147109", "147110", "147111", "147112", "147201", "147202", "147203", "147204",
                "147205", "147206", "147207", "150101", "150102", "150104", "150105", "150106", "150107", "150108",
                "150109", "150111", "150115", "150116", "150117", "150118", "150119", "150121", "150201", "150202",
                "150203", "150204", "150205", "150206", "150207", "150208", "150209", "150210", "150211", "150212",
                "150213", "150214", "150215", "150216", "150217", "150218", "150301", "150302", "150303", "150304",
                "150305", "150306", "150307", "150308", "150309", "150310", "150401", "150402", "150403", "150404",
                "150405", "150406", "150407", "150408", "150501", "150502", "150503", "150504", "150505", "150506",
                "150507", "150508", "150510", "150601", "150602", "150603", "150604", "150605", "150606", "150607",
                "150608", "150609", "150610", "150611", "150612", "150613", "150701", "150702", "150703", "150704",
                "150705", "150706", "150707", "150708", "150709", "150710", "150711", "150801", "150802", "150803",
                "150804", "150805", "150806", "150807", "150808", "150809", "150810", "150811", "150812", "150813",
                "150814", "150815", "150816", "150817", "150901", "150902", "150903", "150904", "150905", "150906",
                "150907", "150908", "150909", "150910", "150911", "150912", "157101", "157102", "157103", "157104",
                "157105", "157106", "157107", "157108", "157201", "157202", "157203", "157204", "157205", "157206",
                "157207", "157208", "160107", "160108", "160109", "160113", "160114", "160120", "160121", "160122",
                "160128", "160129", "160130", "160131", "160202", "160203", "160204", "160205", "160208", "160211",
                "160212", "160213", "160214", "160215", "160217", "160218", "160219", "160220", "160221", "160222",
                "160223", "160224", "160301", "160302", "160303", "160304", "160306", "160307", "160308", "160309",
                "160310", "160311", "160314", "160315", "160316", "160317", "160319", "160321", "160322", "160323",
                "160324", "160325", "160401", "160406", "160407", "160408", "160409", "160410", "160412", "160415",
                "160416", "160417", "160418", "160419", "160420", "160421", "160422", "160423", "160424", "160425",
                "160426", "160427", "160428", "160429", "160501", "160502", "160503", "160508", "160509", "160510",
                "160511", "160512", "160513", "160514", "160518", "160519", "160520", "160521", "160601", "160602",
                "160603", "160604", "160605", "160606", "160607", "160608", "160609", "160610", "160611", "160612",
                "160613", "160614", "160701", "160702", "160703", "160704", "160705", "160706", "160707", "160708",
                "160709", "160710", "160711", "160712", "160713", "160714", "160715", "160716", "160717", "160718",
                "160719", "160801", "160802", "160803", "160804", "160805", "160806", "160807", "160808", "160809",
                "160810", "160811", "160812", "160813", "160814", "160815", "160816", "160817", "160818", "160819",
                "160820", "160901", "160902", "160903", "160904", "160905", "160906", "160907", "160908", "160909",
                "160910", "160911", "160912", "160913", "160914", "160915", "160916", "160917", "160918", "160919",
                "161001", "161002", "161003", "161004", "161005", "161006", "161007", "161008", "161009", "161010",
                "161011", "161012", "161013", "161014", "161015", "161016", "161101", "161102", "161103", "161104",
                "161105", "161106", "161107", "161108", "161109", "161110", "161201", "161202", "161203", "161204",
                "161205", "161301", "161302", "161303", "161304", "161305", "161306", "161307", "167101", "167102",
                "167103", "167104", "167105", "167106", "167107", "167108", "167109", "167110", "167111", "167112",
                "167113", "167114", "167115", "167116", "167201", "167202", "167203", "167204", "167205", "167305",
                "167306", "167307", "167308", "167401", "167402", "167403", "167404", "167405", "167406", "170101",
                "170102", "170103", "170104", "170105", "170106", "170107", "170108", "170109", "170110", "170111",
                "170206", "170207", "170208", "170209", "170210", "170211", "170216", "170217", "170218", "170219",
                "170220", "170221", "170222", "170223", "170224", "170301", "170306", "170307", "170308", "170309",
                "170310", "170311", "170312", "170313", "170314", "170315", "170316", "170319", "170320", "170321",
                "170323", "170401", "170402", "170403", "170404", "170405", "170406", "170407", "170408", "170409",
                "170410", "170411", "170412", "170413", "170414", "170415", "170501", "170502", "170503", "170504",
                "170505", "170506", "170507", "170508", "170509", "170510", "170511", "170512", "170513", "170514",
                "170601", "170602", "170603", "170604", "170605", "170606", "170607", "170608", "170609", "170610",
                "170611", "170612", "170613", "170614", "170615", "170701", "170702", "170703", "170704", "170705",
                "170706", "170707", "170708", "170709", "170710", "170711", "170712", "170801", "170802", "170803",
                "170804", "170805", "170806", "170807", "170808", "170901", "170902", "170903", "170904", "170905",
                "170906", "170907", "170908", "170909", "170910", "177101", "177102", "177103", "177104", "177105",
                "177106", "177107", "177108", "177109", "180104", "180105", "180106", "180107", "180108", "180109",
                "180110", "180113", "180114", "180115", "180116", "180117", "180118", "180121", "180122", "180123",
                "180124", "180201", "180202", "180203", "180204", "180205", "180206", "180207", "180208", "180209",
                "180210", "180211", "180212", "180213", "180214", "180215", "180216", "180217", "180218", "180219",
                "180220", "180221", "180222", "180223", "180224", "180225", "180226", "180227", "180228", "180301",
                "180302", "180303", "180304", "180305", "180306", "180307", "180308", "180309", "180310", "180311",
                "180312", "180313", "180314", "180315", "180316", "180317", "180318", "180319", "180320", "180321",
                "180322", "180323", "180404", "180405", "180406", "180407", "180408", "180409", "180410", "180411",
                "180415", "180418", "180419", "180420", "180421", "180422", "180423", "180502", "180506", "180508",
                "180511", "180512", "180513", "180518", "180520", "180522", "180523", "180525", "180526", "180527",
                "180601", "180602", "180603", "180604", "180609", "180611", "180612", "180613", "180615", "180616",
                "180617", "180618", "180619", "180620", "180621", "180624", "180625", "180626", "180627", "180628",
                "180701", "180702", "180703", "180704", "180705", "180706", "180707", "180708", "180709", "180710",
                "180711", "180712", "180713", "180714", "180715", "180716", "180717", "180718", "180719", "180720",
                "180721", "180722", "180723", "180724", "180801", "180802", "180803", "180804", "180805", "180806",
                "180807", "180808", "180809", "180810", "180811", "180812", "180813", "180814", "180901", "180902",
                "180903", "180904", "180905", "180906", "180907", "180908", "180909", "181001", "181002", "181003",
                "181004", "181005", "181006", "181007", "181008", "181009", "181101", "181102", "181103", "181104",
                "181105", "181106", "181107", "181201", "181202", "181203", "181204", "181205", "181206", "181207",
                "181208", "181301", "181302", "181303", "181304", "181305", "181306", "181307", "181308", "181309",
                "181310", "181311", "187101", "187102", "187103", "187104", "187105", "187106", "187107", "187108",
                "187109", "187110", "187111", "187112", "187113", "187114", "187115", "187116", "187117", "187118",
                "187119", "187120", "187201", "187202", "187203", "187204", "187205", "190101", "190102", "190103",
                "190104", "190105", "190106", "190107", "190108", "190201", "190202", "190203", "190204", "190205",
                "190301", "190302", "190303", "190304", "190305", "190306", "190307", "190308", "190401", "190402",
                "190403", "190404", "190405", "190406", "190501", "190502", "190503", "190504", "190505", "190506",
                "190601", "190602", "190603", "190604", "190605", "190606", "190607", "197101", "197102", "197103",
                "197104", "197105", "197106", "197107", "210104", "210106", "210107", "210108", "210109", "210110",
                "210112", "210113", "210114", "210115", "210201", "210202", "210203", "210204", "210205", "210206",
                "210207", "210208", "210209", "210210", "210211", "210212", "210304", "210305", "210306", "210307",
                "210308", "210309", "210310", "210311", "210315", "210316", "210401", "210402", "210403", "210404",
                "210405", "210406", "210407", "210408", "210409", "210501", "210502", "210503", "210504", "210505",
                "210506", "210507", "217101", "217102", "217103", "217104", "217105", "217106", "217107", "217108",
                "217109", "217110", "217111", "217112", "217201", "217202", "217203", "217204", "310101", "310102",
                "317101", "317102", "317103", "317104", "317105", "317106", "317107", "317108", "317201", "317202",
                "317203", "317204", "317205", "317206", "317301", "317302", "317303", "317304", "317305", "317306",
                "317307", "317308", "317401", "317402", "317403", "317404", "317405", "317406", "317407", "317408",
                "317409", "317410", "317501", "317502", "317503", "317504", "317505", "317506", "317507", "317508",
                "317509", "317510", "320101", "320102", "320103", "320104", "320105", "320106", "320107", "320108",
                "320109", "320110", "320111", "320112", "320113", "320114", "320115", "320116", "320117", "320118",
                "320119", "320120", "320121", "320122", "320123", "320124", "320125", "320126", "320127", "320128",
                "320129", "320130", "320131", "320132", "320133", "320134", "320135", "320136", "320137", "320138",
                "320139", "320140", "320201", "320202", "320203", "320204", "320205", "320206", "320207", "320208",
                "320209", "320210", "320211", "320212", "320213", "320214", "320215", "320216", "320217", "320218",
                "320219", "320220", "320221", "320222", "320223", "320224", "320225", "320226", "320227", "320228",
                "320229", "320230", "320231", "320232", "320233", "320234", "320235", "320236", "320237", "320238",
                "320239", "320240", "320241", "320242", "320243", "320244", "320245", "320246", "320247", "320301",
                "320302", "320303", "320304", "320305", "320306", "320307", "320308", "320309", "320310", "320311",
                "320312", "320313", "320314", "320315", "320316", "320317", "320318", "320319", "320320", "320321",
                "320322", "320323", "320324", "320325", "320326", "320327", "320328", "320329", "320330", "320331",
                "320332", "320405", "320406", "320407", "320408", "320409", "320410", "320411", "320412", "320413",
                "320414", "320415", "320416", "320417", "320425", "320426", "320427", "320428", "320429", "320430",
                "320431", "320432", "320433", "320434", "320435", "320436", "320437", "320438", "320439", "320440",
                "320444", "320446", "320501", "320502", "320503", "320504", "320505", "320506", "320507", "320508",
                "320509", "320510", "320511", "320512", "320513", "320514", "320515", "320516", "320517", "320518",
                "320519", "320520", "320521", "320522", "320523", "320524", "320525", "320526", "320527", "320528",
                "320529", "320530", "320531", "320532", "320533", "320534", "320535", "320536", "320537", "320538",
                "320539", "320540", "320541", "320542", "320601", "320602", "320603", "320604", "320605", "320606",
                "320607", "320608", "320609", "320610", "320611", "320612", "320613", "320614", "320615", "320616",
                "320617", "320618", "320619", "320620", "320621", "320622", "320623", "320624", "320625", "320626",
                "320627", "320628", "320629", "320630", "320631", "320632", "320633", "320634", "320635", "320636",
                "320637", "320638", "320639", "320701", "320702", "320703", "320704", "320705", "320706", "320707",
                "320708", "320709", "320710", "320711", "320712", "320713", "320714", "320715", "320716", "320717",
                "320718", "320719", "320729", "320730", "320731", "320732", "320733", "320734", "320735", "320801",
                "320802", "320803", "320804", "320805", "320806", "320807", "320808", "320809", "320810", "320811",
                "320812", "320813", "320814", "320815", "320816", "320817", "320818", "320819", "320820", "320821",
                "320822", "320823", "320824", "320825", "320826", "320827", "320828", "320829", "320830", "320831",
                "320832", "320901", "320902", "320903", "320904", "320905", "320906", "320907", "320908", "320909",
                "320910", "320911", "320912", "320913", "320914", "320915", "320916", "320917", "320918", "320919",
                "320920", "320921", "320922", "320923", "320924", "320925", "320926", "320927", "320928", "320929",
                "320930", "320931", "320932", "320933", "320934", "320935", "320936", "320937", "320938", "320939",
                "320940", "321001", "321002", "321003", "321004", "321005", "321006", "321007", "321008", "321009",
                "321010", "321011", "321012", "321013", "321014", "321015", "321016", "321017", "321018", "321019",
                "321020", "321021", "321022", "321023", "321024", "321025", "321026", "321101", "321102", "321103",
                "321104", "321105", "321106", "321107", "321108", "321109", "321110", "321111", "321112", "321113",
                "321114", "321115", "321116", "321117", "321118", "321119", "321120", "321121", "321122", "321123",
                "321124", "321125", "321126", "321201", "321202", "321203", "321204", "321205", "321206", "321207",
                "321208", "321209", "321210", "321211", "321212", "321213", "321214", "321215", "321216", "321217",
                "321218", "321219", "321220", "321221", "321222", "321223", "321224", "321225", "321226", "321227",
                "321228", "321229", "321230", "321231", "321301", "321302", "321303", "321304", "321305", "321306",
                "321307", "321308", "321309", "321310", "321311", "321312", "321313", "321314", "321315", "321316",
                "321317", "321318", "321319", "321320", "321321", "321322", "321323", "321324", "321325", "321326",
                "321327", "321328", "321329", "321330", "321401", "321402", "321403", "321404", "321405", "321406",
                "321407", "321408", "321409", "321410", "321411", "321412", "321413", "321414", "321415", "321416",
                "321417", "321501", "321502", "321503", "321504", "321505", "321506", "321507", "321508", "321509",
                "321510", "321511", "321512", "321513", "321514", "321515", "321516", "321517", "321518", "321519",
                "321520", "321521", "321522", "321523", "321524", "321525", "321526", "321527", "321528", "321529",
                "321530", "321601", "321602", "321603", "321604", "321605", "321606", "321607", "321608", "321609",
                "321610", "321611", "321612", "321613", "321614", "321615", "321616", "321617", "321618", "321619",
                "321620", "321621", "321622", "321623", "321701", "321702", "321703", "321704", "321705", "321706",
                "321707", "321708", "321709", "321710", "321711", "321712", "321713", "321714", "321715", "321716",
                "321801", "321802", "321803", "321804", "321805", "321806", "321807", "321808", "321809", "321810",
                "327101", "327102", "327103", "327104", "327105", "327106", "327201", "327202", "327203", "327204",
                "327205", "327206", "327207", "327301", "327302", "327303", "327304", "327305", "327306", "327307",
                "327308", "327309", "327310", "327311", "327312", "327313", "327314", "327315", "327316", "327317",
                "327318", "327319", "327320", "327321", "327322", "327323", "327324", "327325", "327326", "327327",
                "327328", "327329", "327330", "327401", "327402", "327403", "327404", "327405", "327501", "327502",
                "327503", "327504", "327505", "327506", "327507", "327508", "327509", "327510", "327511", "327512",
                "327601", "327602", "327603", "327604", "327605", "327606", "327607", "327608", "327609", "327610",
                "327611", "327701", "327702", "327703", "327801", "327802", "327803", "327804", "327805", "327806",
                "327807", "327808", "327809", "327810", "327901", "327902", "327903", "327904", "330101", "330102",
                "330103", "330104", "330105", "330106", "330107", "330108", "330109", "330110", "330111", "330112",
                "330113", "330114", "330115", "330116", "330117", "330118", "330119", "330120", "330121", "330122",
                "330123", "330124", "330201", "330202", "330203", "330204", "330205", "330206", "330207", "330208",
                "330209", "330210", "330211", "330212", "330213", "330214", "330215", "330216", "330217", "330218",
                "330219", "330220", "330221", "330222", "330223", "330224", "330225", "330226", "330227", "330301",
                "330302", "330303", "330304", "330305", "330306", "330307", "330308", "330309", "330310", "330311",
                "330312", "330313", "330314", "330315", "330316", "330317", "330318", "330401", "330402", "330403",
                "330404", "330405", "330406", "330407", "330408", "330409", "330410", "330411", "330412", "330413",
                "330414", "330415", "330416", "330417", "330418", "330419", "330420", "330501", "330502", "330503",
                "330504", "330505", "330506", "330507", "330508", "330509", "330510", "330511", "330512", "330513",
                "330514", "330515", "330516", "330517", "330518", "330519", "330520", "330521", "330522", "330523",
                "330524", "330525", "330526", "330601", "330602", "330603", "330604", "330605", "330606", "330607",
                "330608", "330609", "330610", "330611", "330612", "330613", "330614", "330615", "330616", "330701",
                "330702", "330703", "330704", "330705", "330706", "330707", "330708", "330709", "330710", "330711",
                "330712", "330713", "330714", "330715", "330801", "330802", "330803", "330804", "330805", "330806",
                "330807", "330808", "330809", "330810", "330811", "330812", "330813", "330814", "330815", "330816",
                "330817", "330818", "330819", "330820", "330821", "330901", "330902", "330903", "330904", "330905",
                "330906", "330907", "330908", "330909", "330910", "330911", "330912", "330913", "330914", "330915",
                "330916", "330917", "330918", "330919", "331001", "331002", "331003", "331004", "331005", "331006",
                "331007", "331008", "331009", "331010", "331011", "331012", "331013", "331014", "331015", "331016",
                "331017", "331018", "331019", "331020", "331021", "331022", "331023", "331024", "331025", "331026",
                "331101", "331102", "331103", "331104", "331105", "331106", "331107", "331108", "331109", "331110",
                "331111", "331112", "331201", "331202", "331203", "331204", "331205", "331206", "331207", "331208",
                "331209", "331210", "331211", "331212", "331213", "331214", "331215", "331216", "331217", "331218",
                "331219", "331220", "331221", "331222", "331223", "331224", "331225", "331301", "331302", "331303",
                "331304", "331305", "331306", "331307", "331308", "331309", "331310", "331311", "331312", "331313",
                "331314", "331315", "331316", "331317", "331401", "331402", "331403", "331404", "331405", "331406",
                "331407", "331408", "331409", "331410", "331411", "331412", "331413", "331414", "331415", "331416",
                "331417", "331418", "331419", "331420", "331501", "331502", "331503", "331504", "331505", "331506",
                "331507", "331508", "331509", "331510", "331511", "331512", "331513", "331514", "331515", "331516",
                "331517", "331518", "331519", "331601", "331602", "331603", "331604", "331605", "331606", "331607",
                "331608", "331609", "331610", "331611", "331612", "331613", "331614", "331615", "331616", "331701",
                "331702", "331703", "331704", "331705", "331706", "331707", "331708", "331709", "331710", "331711",
                "331712", "331713", "331714", "331801", "331802", "331803", "331804", "331805", "331806", "331807",
                "331808", "331809", "331810", "331811", "331812", "331813", "331814", "331815", "331816", "331817",
                "331818", "331819", "331820", "331821", "331901", "331902", "331903", "331904", "331905", "331906",
                "331907", "331908", "331909", "332001", "332002", "332003", "332004", "332005", "332006", "332007",
                "332008", "332009", "332010", "332011", "332012", "332013", "332014", "332015", "332016", "332101",
                "332102", "332103", "332104", "332105", "332106", "332107", "332108", "332109", "332110", "332111",
                "332112", "332113", "332114", "332201", "332202", "332203", "332204", "332205", "332206", "332207",
                "332208", "332209", "332210", "332211", "332212", "332213", "332215", "332216", "332217", "332218",
                "332219", "332220", "332301", "332302", "332303", "332304", "332305", "332306", "332307", "332308",
                "332309", "332310", "332311", "332312", "332313", "332314", "332315", "332316", "332317", "332318",
                "332319", "332320", "332401", "332402", "332403", "332404", "332405", "332406", "332407", "332408",
                "332409", "332410", "332411", "332412", "332413", "332414", "332415", "332416", "332417", "332418",
                "332419", "332420", "332501", "332502", "332503", "332504", "332505", "332506", "332507", "332508",
                "332509", "332510", "332511", "332512", "332513", "332514", "332515", "332601", "332602", "332603",
                "332604", "332605", "332606", "332607", "332608", "332609", "332610", "332611", "332612", "332613",
                "332614", "332615", "332616", "332617", "332618", "332619", "332701", "332702", "332703", "332704",
                "332705", "332706", "332707", "332708", "332709", "332710", "332711", "332712", "332713", "332714",
                "332801", "332802", "332803", "332804", "332805", "332806", "332807", "332808", "332809", "332810",
                "332811", "332812", "332813", "332814", "332815", "332816", "332817", "332818", "332901", "332902",
                "332903", "332904", "332905", "332906", "332907", "332908", "332909", "332910", "332911", "332912",
                "332913", "332914", "332915", "332916", "332917", "337101", "337102", "337103", "337201", "337202",
                "337203", "337204", "337205", "337301", "337302", "337303", "337304", "337401", "337402", "337403",
                "337404", "337405", "337406", "337407", "337408", "337409", "337410", "337411", "337412", "337413",
                "337414", "337415", "337416", "337501", "337502", "337503", "337504", "337601", "337602", "337603",
                "337604", "340101", "340102", "340103", "340104", "340105", "340106", "340107", "340108", "340109",
                "340110", "340111", "340112", "340201", "340202", "340203", "340204", "340205", "340206", "340207",
                "340208", "340209", "340210", "340211", "340212", "340213", "340214", "340215", "340216", "340217",
                "340301", "340302", "340303", "340304", "340305", "340306", "340307", "340308", "340309", "340310",
                "340311", "340312", "340313", "340314", "340315", "340316", "340317", "340318", "340401", "340402",
                "340403", "340404", "340405", "340406", "340407", "340408", "340409", "340410", "340411", "340412",
                "340413", "340414", "340415", "340416", "340417", "347101", "347102", "347103", "347104", "347105",
                "347106", "347107", "347108", "347109", "347110", "347111", "347112", "347113", "347114", "350101",
                "350102", "350103", "350104", "350105", "350106", "350107", "350108", "350109", "350110", "350111",
                "350112", "350201", "350202", "350203", "350204", "350205", "350206", "350207", "350208", "350209",
                "350210", "350211", "350212", "350213", "350214", "350215", "350216", "350217", "350218", "350219",
                "350220", "350221", "350301", "350302", "350303", "350304", "350305", "350306", "350307", "350308",
                "350309", "350310", "350311", "350312", "350313", "350314", "350401", "350402", "350403", "350404",
                "350405", "350406", "350407", "350408", "350409", "350410", "350411", "350412", "350413", "350414",
                "350415", "350416", "350417", "350418", "350419", "350501", "350502", "350503", "350504", "350505",
                "350506", "350507", "350508", "350509", "350510", "350511", "350512", "350513", "350514", "350515",
                "350516", "350517", "350518", "350519", "350520", "350521", "350522", "350601", "350602", "350603",
                "350604", "350605", "350606", "350607", "350608", "350609", "350610", "350611", "350612", "350613",
                "350614", "350615", "350616", "350617", "350618", "350619", "350620", "350621", "350622", "350623",
                "350624", "350625", "350626", "350701", "350702", "350703", "350704", "350705", "350706", "350707",
                "350708", "350709", "350710", "350711", "350712", "350713", "350714", "350715", "350716", "350717",
                "350718", "350719", "350720", "350721", "350722", "350723", "350724", "350725", "350726", "350727",
                "350728", "350729", "350730", "350731", "350732", "350733", "350801", "350802", "350803", "350804",
                "350805", "350806", "350807", "350808", "350809", "350810", "350811", "350812", "350813", "350814",
                "350815", "350816", "350817", "350818", "350819", "350820", "350821", "350901", "350902", "350903",
                "350904", "350905", "350906", "350907", "350908", "350909", "350910", "350911", "350912", "350913",
                "350914", "350915", "350916", "350917", "350918", "350919", "350920", "350921", "350922", "350923",
                "350924", "350925", "350926", "350927", "350928", "350929", "350930", "350931", "351001", "351002",
                "351003", "351004", "351005", "351006", "351007", "351008", "351009", "351010", "351011", "351012",
                "351013", "351014", "351015", "351016", "351017", "351018", "351019", "351020", "351021", "351022",
                "351023", "351024", "351101", "351102", "351103", "351104", "351105", "351106", "351107", "351108",
                "351109", "351110", "351111", "351112", "351113", "351114", "351115", "351116", "351117", "351118",
                "351119", "351120", "351121", "351122", "351123", "351201", "351202", "351203", "351204", "351205",
                "351206", "351207", "351208", "351209", "351210", "351211", "351212", "351213", "351214", "351215",
                "351216", "351217", "351301", "351302", "351303", "351304", "351305", "351306", "351307", "351308",
                "351309", "351310", "351311", "351312", "351313", "351314", "351315", "351316", "351317", "351318",
                "351319", "351320", "351321", "351322", "351323", "351324", "351401", "351402", "351403", "351404",
                "351405", "351406", "351407", "351408", "351409", "351410", "351411", "351412", "351413", "351414",
                "351415", "351416", "351417", "351418", "351419", "351420", "351421", "351422", "351423", "351424",
                "351501", "351502", "351503", "351504", "351505", "351506", "351507", "351508", "351509", "351510",
                "351511", "351512", "351513", "351514", "351515", "351516", "351517", "351518", "351601", "351602",
                "351603", "351604", "351605", "351606", "351607", "351608", "351609", "351610", "351611", "351612",
                "351613", "351614", "351615", "351616", "351617", "351618", "351701", "351702", "351703", "351704",
                "351705", "351706", "351707", "351708", "351709", "351710", "351711", "351712", "351713", "351714",
                "351715", "351716", "351717", "351718", "351719", "351720", "351721", "351801", "351802", "351803",
                "351804", "351805", "351806", "351807", "351808", "351809", "351810", "351811", "351812", "351813",
                "351814", "351815", "351816", "351817", "351818", "351819", "351820", "351901", "351902", "351903",
                "351904", "351905", "351906", "351907", "351908", "351909", "351910", "351911", "351912", "351913",
                "351914", "351915", "352001", "352002", "352003", "352004", "352005", "352006", "352007", "352008",
                "352009", "352010", "352011", "352012", "352013", "352014", "352015", "352016", "352017", "352018",
                "352101", "352102", "352103", "352104", "352105", "352106", "352107", "352108", "352109", "352110",
                "352111", "352112", "352113", "352114", "352115", "352116", "352117", "352118", "352119", "352201",
                "352202", "352203", "352204", "352205", "352206", "352207", "352208", "352209", "352210", "352211",
                "352212", "352213", "352214", "352215", "352216", "352217", "352218", "352219", "352220", "352221",
                "352222", "352223", "352224", "352225", "352226", "352227", "352228", "352301", "352302", "352303",
                "352304", "352305", "352306", "352307", "352308", "352309", "352310", "352311", "352312", "352313",
                "352314", "352315", "352316", "352317", "352318", "352319", "352320", "352401", "352402", "352403",
                "352404", "352405", "352406", "352407", "352408", "352409", "352410", "352411", "352412", "352413",
                "352414", "352415", "352416", "352417", "352418", "352419", "352420", "352421", "352422", "352423",
                "352424", "352425", "352426", "352427", "352501", "352502", "352503", "352504", "352505", "352506",
                "352507", "352508", "352509", "352510", "352511", "352512", "352513", "352514", "352515", "352516",
                "352517", "352518", "352601", "352602", "352603", "352604", "352605", "352606", "352607", "352608",
                "352609", "352610", "352611", "352612", "352613", "352614", "352615", "352616", "352617", "352618",
                "352701", "352702", "352703", "352704", "352705", "352706", "352707", "352708", "352709", "352710",
                "352711", "352712", "352713", "352714", "352801", "352802", "352803", "352804", "352805", "352806",
                "352807", "352808", "352809", "352810", "352811", "352812", "352813", "352901", "352902", "352903",
                "352904", "352905", "352906", "352907", "352908", "352909", "352910", "352911", "352912", "352913",
                "352914", "352915", "352916", "352917", "352918", "352919", "352920", "352921", "352922", "352923",
                "352924", "352925", "352926", "352927", "357101", "357102", "357103", "357201", "357202", "357203",
                "357301", "357302", "357303", "357304", "357305", "357401", "357402", "357403", "357404", "357405",
                "357501", "357502", "357503", "357504", "357601", "357602", "357701", "357702", "357703", "357801",
                "357802", "357803", "357804", "357805", "357806", "357807", "357808", "357809", "357810", "357811",
                "357812", "357813", "357814", "357815", "357816", "357817", "357818", "357819", "357820", "357821",
                "357822", "357823", "357824", "357825", "357826", "357827", "357828", "357829", "357830", "357831",
                "357901", "357902", "357903", "360101", "360102", "360103", "360104", "360105", "360106", "360107",
                "360108", "360109", "360110", "360111", "360112", "360113", "360114", "360115", "360116", "360117",
                "360118", "360119", "360120", "360121", "360122", "360123", "360124", "360125", "360126", "360127",
                "360128", "360129", "360130", "360131", "360132", "360133", "360134", "360135", "360201", "360202",
                "360203", "360204", "360205", "360206", "360207", "360208", "360209", "360210", "360211", "360212",
                "360213", "360214", "360215", "360216", "360217", "360218", "360219", "360220", "360221", "360222",
                "360223", "360224", "360225", "360226", "360227", "360228", "360301", "360302", "360303", "360304",
                "360305", "360306", "360307", "360308", "360309", "360310", "360311", "360312", "360313", "360314",
                "360315", "360316", "360317", "360318", "360319", "360320", "360322", "360323", "360327", "360328",
                "360329", "360330", "360331", "360332", "360333", "360405", "360406", "360407", "360408", "360409",
                "360411", "360412", "360413", "360414", "360415", "360416", "360417", "360418", "360419", "360420",
                "360422", "360423", "360424", "360425", "360426", "360427", "360428", "360429", "360430", "360431",
                "360432", "360433", "360434", "367101", "367102", "367103", "367104", "367105", "367106", "367107",
                "367108", "367109", "367110", "367111", "367112", "367113", "367201", "367202", "367203", "367204",
                "367205", "367206", "367207", "367208", "367301", "367302", "367303", "367304", "367305", "367306",
                "367401", "367402", "367403", "367404", "367405", "367406", "367407", "510101", "510102", "510103",
                "510104", "510105", "510201", "510202", "510203", "510204", "510205", "510206", "510207", "510208",
                "510209", "510210", "510301", "510302", "510303", "510304", "510305", "510306", "510401", "510402",
                "510403", "510404", "510405", "510406", "510407", "510501", "510502", "510503", "510504", "510601",
                "510602", "510603", "510604", "510701", "510702", "510703", "510704", "510705", "510706", "510707",
                "510708", "510801", "510802", "510803", "510804", "510805", "510806", "510807", "510808", "510809",
                "517101", "517102", "517103", "517104", "520101", "520102", "520103", "520107", "520108", "520109",
                "520112", "520113", "520114", "520115", "520201", "520202", "520203", "520204", "520205", "520206",
                "520207", "520208", "520209", "520210", "520211", "520212", "520301", "520302", "520303", "520304",
                "520305", "520306", "520307", "520308", "520309", "520310", "520311", "520312", "520313", "520314",
                "520315", "520316", "520317", "520318", "520319", "520320", "520402", "520405", "520406", "520407",
                "520408", "520409", "520410", "520411", "520412", "520413", "520414", "520417", "520418", "520419",
                "520420", "520421", "520422", "520423", "520424", "520425", "520426", "520427", "520428", "520429",
                "520501", "520502", "520503", "520504", "520505", "520506", "520507", "520508", "520601", "520602",
                "520603", "520604", "520605", "520606", "520607", "520608", "520609", "520610", "520611", "520612",
                "520613", "520614", "520615", "520616", "520617", "520618", "520701", "520702", "520703", "520704",
                "520705", "520706", "520707", "520708", "520801", "520802", "520803", "520804", "520805", "527101",
                "527102", "527103", "527104", "527105", "527106", "527201", "527202", "527203", "527204", "527205",
                "530104", "530105", "530106", "530107", "530108", "530109", "530110", "530111", "530112", "530113",
                "530116", "530117", "530118", "530119", "530120", "530121", "530122", "530123", "530124", "530125",
                "530126", "530127", "530128", "530130", "530201", "530202", "530203", "530204", "530205", "530206",
                "530207", "530208", "530209", "530210", "530211", "530212", "530213", "530214", "530215", "530216",
                "530217", "530218", "530219", "530220", "530221", "530222", "530223", "530224", "530225", "530226",
                "530227", "530228", "530229", "530230", "530231", "530232", "530301", "530302", "530303", "530304",
                "530305", "530306", "530307", "530308", "530309", "530310", "530311", "530312", "530313", "530314",
                "530315", "530316", "530317", "530318", "530319", "530320", "530321", "530322", "530323", "530324",
                "530401", "530402", "530403", "530404", "530405", "530412", "530413", "530417", "530418", "530421",
                "530422", "530423", "530501", "530502", "530503", "530504", "530505", "530506", "530507", "530508",
                "530509", "530510", "530511", "530512", "530513", "530514", "530515", "530516", "530517", "530601",
                "530602", "530603", "530604", "530605", "530606", "530607", "530608", "530609", "530610", "530611",
                "530612", "530613", "530614", "530615", "530616", "530617", "530618", "530619", "530701", "530702",
                "530703", "530704", "530705", "530706", "530707", "530708", "530709", "530710", "530711", "530712",
                "530713", "530714", "530715", "530716", "530717", "530718", "530719", "530720", "530721", "530801",
                "530802", "530803", "530804", "530805", "530806", "530807", "530808", "530809", "530810", "530811",
                "530812", "530813", "530814", "530815", "530816", "530817", "530818", "530819", "530820", "530821",
                "530901", "530902", "530906", "530907", "530909", "530912", "530914", "530915", "530916", "530918",
                "530919", "530920", "531001", "531003", "531005", "531006", "531011", "531012", "531013", "531014",
                "531015", "531016", "531017", "531101", "531102", "531103", "531104", "531105", "531106", "531107",
                "531108", "531109", "531110", "531111", "531112", "531113", "531114", "531115", "531116", "531117",
                "531118", "531119", "531120", "531121", "531122", "531204", "531210", "531211", "531212", "531215",
                "531218", "531301", "531302", "531303", "531304", "531305", "531306", "531307", "531308", "531309",
                "531401", "531402", "531403", "531404", "531405", "531406", "531407", "531408", "531409", "531410",
                "531501", "531502", "531503", "531504", "531505", "531506", "531507", "531508", "531509", "531510",
                "531601", "531602", "531603", "531604", "531605", "531606", "531607", "531701", "531702", "531703",
                "531704", "531705", "531801", "531802", "531803", "531804", "531805", "531806", "531807", "531808",
                "531809", "531810", "531811", "531901", "531902", "531903", "531904", "531905", "531906", "531907",
                "531908", "531909", "532001", "532002", "532003", "532004", "532005", "532006", "532101", "532102",
                "532103", "532104", "532105", "532106", "532107", "532108", "532109", "532110", "532111", "532112",
                "537101", "537102", "537103", "537104", "537105", "537106", "610101", "610102", "610103", "610104",
                "610105", "610106", "610107", "610108", "610109", "610110", "610111", "610112", "610113", "610114",
                "610115", "610116", "610117", "610118", "610119", "610201", "610206", "610207", "610208", "610212",
                "610215", "610216", "610217", "610218", "610301", "610302", "610303", "610304", "610305", "610306",
                "610307", "610308", "610309", "610310", "610311", "610312", "610313", "610320", "610321", "610401",
                "610402", "610403", "610404", "610405", "610407", "610408", "610411", "610412", "610413", "610414",
                "610416", "610417", "610418", "610419", "610420", "610421", "610422", "610424", "610425", "610501",
                "610502", "610503", "610504", "610505", "610506", "610507", "610508", "610509", "610514", "610515",
                "610519", "610520", "610521", "610601", "610602", "610603", "610604", "610605", "610606", "610607",
                "610608", "610609", "610610", "610611", "610612", "610613", "610614", "610615", "610616", "610617",
                "610618", "610619", "610620", "610621", "610622", "610623", "610701", "610702", "610703", "610704",
                "610705", "610706", "610707", "610708", "610709", "610710", "610711", "610712", "610713", "610714",
                "610715", "610716", "610717", "610801", "610802", "610803", "610804", "610805", "610806", "610807",
                "610808", "610809", "610810", "610811", "610812", "610813", "610901", "610902", "610903", "610904",
                "610905", "610906", "610907", "611001", "611002", "611003", "611004", "611005", "611006", "611007",
                "611008", "611009", "611010", "611011", "611101", "611102", "611103", "611105", "611106", "611201",
                "611202", "611203", "611204", "611205", "611206", "611207", "611208", "611209", "617101", "617102",
                "617103", "617104", "617105", "617106", "617201", "617202", "617203", "617204", "617205", "620101",
                "620102", "620103", "620104", "620105", "620106", "620201", "620202", "620203", "620204", "620205",
                "620206", "620207", "620208", "620209", "620210", "620211", "620212", "620213", "620214", "620215",
                "620216", "620217", "620301", "620302", "620303", "620304", "620305", "620306", "620307", "620308",
                "620309", "620310", "620311", "620312", "620313", "620314", "620315", "620316", "620317", "620401",
                "620402", "620403", "620404", "620405", "620406", "620501", "620502", "620503", "620504", "620505",
                "620506", "620508", "620509", "620601", "620602", "620603", "620604", "620605", "620606", "620607",
                "620608", "620609", "620610", "620611", "620612", "620613", "620701", "620702", "620703", "620704",
                "620705", "620706", "620707", "620708", "620709", "620710", "620801", "620802", "620803", "620804",
                "620805", "620901", "620902", "620903", "620904", "620905", "620906", "620907", "620908", "621001",
                "621002", "621003", "621004", "621005", "621006", "621007", "621008", "621009", "621010", "621011",
                "621101", "621102", "621103", "621104", "621105", "621106", "621107", "621108", "621201", "621202",
                "621203", "621204", "621205", "621206", "621207", "621208", "621209", "621210", "621301", "621302",
                "621303", "621304", "621305", "621306", "621307", "621308", "621309", "621310", "627101", "627102",
                "627103", "627104", "627105", "630101", "630102", "630103", "630104", "630105", "630106", "630107",
                "630108", "630109", "630110", "630111", "630201", "630202", "630203", "630204", "630205", "630206",
                "630207", "630208", "630209", "630210", "630211", "630212", "630213", "630214", "630215", "630216",
                "630217", "630218", "630219", "630220", "630221", "630301", "630302", "630303", "630304", "630305",
                "630306", "630307", "630308", "630309", "630310", "630311", "630312", "630313", "630314", "630315",
                "630316", "630317", "630318", "630319", "630401", "630402", "630403", "630404", "630405", "630406",
                "630407", "630408", "630409", "630410", "630411", "630412", "630413", "630414", "630415", "630416",
                "630417", "630501", "630502", "630503", "630504", "630505", "630506", "630507", "630508", "630509",
                "630510", "630511", "630512", "630601", "630602", "630603", "630604", "630605", "630606", "630607",
                "630608", "630609", "630610", "630611", "630701", "630702", "630703", "630704", "630705", "630706",
                "630707", "630708", "630709", "630710", "630711", "630801", "630802", "630803", "630804", "630805",
                "630806", "630807", "630808", "630809", "630810", "630901", "630902", "630903", "630904", "630905",
                "630906", "630907", "630908", "630909", "630910", "630911", "630912", "631001", "631002", "631003",
                "631004", "631005", "631006", "631007", "631008", "631009", "631010", "631101", "631102", "631103",
                "631104", "631105", "631106", "631107", "631108", "637101", "637102", "637103", "637104", "637105",
                "637202", "637203", "637204", "637205", "637206", "640101", "640102", "640103", "640104", "640105",
                "640106", "640107", "640108", "640109", "640110", "640201", "640202", "640203", "640204", "640205",
                "640206", "640207", "640208", "640209", "640210", "640211", "640212", "640213", "640214", "640215",
                "640216", "640217", "640218", "640301", "640302", "640303", "640304", "640305", "640306", "640307",
                "640308", "640309", "640310", "640311", "640312", "640313", "640705", "640706", "640707", "640708",
                "640709", "640710", "640711", "640712", "640713", "640714", "640715", "640716", "640717", "640718",
                "640719", "640720", "640801", "640802", "640803", "640804", "640805", "640806", "640807", "640808",
                "640809", "640810", "640811", "640812", "640813", "640814", "640815", "640816", "640817", "640818",
                "640901", "640902", "640903", "640904", "641101", "641102", "641103", "641104", "641105", "647101",
                "647102", "647103", "647104", "647105", "647106", "647201", "647202", "647203", "647204", "647205",
                "647206", "647207", "647208", "647209", "647210", "647401", "647402", "647403", "650101", "650102",
                "650103", "650104", "650105", "650106", "650107", "650108", "650109", "650110", "650201", "650202",
                "650203", "650204", "650205", "650206", "650207", "650208", "650209", "650210", "650211", "650212",
                "650213", "650214", "650215", "650301", "650302", "650303", "650304", "650305", "650306", "650307",
                "650308", "650309", "650310", "650311", "650312", "650313", "650314", "650315", "650316", "650401",
                "650402", "650403", "650405", "657101", "657102", "657103", "657104", "710105", "710109", "710110",
                "710111", "710112", "710113", "710114", "710119", "710120", "710122", "710131", "710132", "710133",
                "710134", "710135", "710201", "710202", "710203", "710204", "710205", "710206", "710207", "710208",
                "710209", "710210", "710211", "710212", "710213", "710214", "710215", "710216", "710217", "710218",
                "710219", "710220", "710221", "710222", "710223", "710224", "710225", "710308", "710309", "710310",
                "710311", "710312", "710313", "710314", "710315", "710316", "710317", "710319", "710320", "710323",
                "710324", "710325", "710401", "710402", "710403", "710404", "710405", "710406", "710407", "710408",
                "710409", "710410", "710411", "710412", "710413", "710414", "710415", "710416", "710417", "710418",
                "710419", "710501", "710502", "710503", "710507", "710508", "710509", "710510", "710512", "710513",
                "710515", "710516", "710517", "710518", "710519", "710521", "710522", "710523", "710601", "710602",
                "710603", "710604", "710605", "710606", "710607", "710608", "710609", "710610", "710701", "710702",
                "710703", "710704", "710705", "710706", "710707", "710708", "710709", "710710", "710711", "710712",
                "710801", "710802", "710803", "710804", "710805", "710806", "710901", "710902", "710903", "710904",
                "710905", "710906", "710907", "710908", "710909", "710910", "711001", "711002", "711003", "711004",
                "711005", "711101", "711102", "711103", "711104", "711105", "717101", "717102", "717103", "717104",
                "717105", "717106", "717107", "717108", "717109", "717110", "717111", "717201", "717202", "717203",
                "717204", "717205", "717206", "717207", "717208", "717301", "717302", "717303", "717304", "717305",
                "717401", "717402", "717403", "717404", "720101", "720102", "720103", "720104", "720105", "720106",
                "720107", "720108", "720109", "720110", "720111", "720112", "720113", "720114", "720115", "720116",
                "720117", "720118", "720119", "720120", "720121", "720122", "720123", "720201", "720202", "720203",
                "720204", "720205", "720206", "720207", "720208", "720209", "720218", "720219", "720220", "720221",
                "720222", "720223", "720224", "720225", "720226", "720227", "720304", "720308", "720309", "720310",
                "720311", "720312", "720314", "720318", "720319", "720321", "720324", "720325", "720327", "720330",
                "720331", "720401", "720402", "720403", "720404", "720405", "720406", "720407", "720408", "720409",
                "720410", "720501", "720502", "720503", "720504", "720505", "720507", "720508", "720509", "720510",
                "720511", "720605", "720606", "720607", "720608", "720609", "720610", "720612", "720615", "720618",
                "720703", "720704", "720705", "720706", "720707", "720709", "720711", "720715", "720716", "720717",
                "720718", "720719", "720801", "720802", "720803", "720804", "720805", "720806", "720807", "720808",
                "720809", "720810", "720811", "720812", "720813", "720814", "720815", "720816", "720817", "720818",
                "720819", "720820", "720821", "720822", "720823", "720901", "720902", "720903", "720904", "720905",
                "720906", "720907", "720908", "720909", "720910", "720911", "720912", "721001", "721002", "721003",
                "721004", "721005", "721006", "721007", "721008", "721009", "721010", "721011", "721012", "721013",
                "721014", "721015", "721101", "721102", "721103", "721104", "721105", "721106", "721107", "721201",
                "721202", "721203", "721204", "721205", "721206", "721207", "721208", "721209", "727101", "727102",
                "727103", "727104", "727105", "727106", "727107", "727108", "730101", "730102", "730103", "730104",
                "730105", "730106", "730107", "730108", "730109", "730110", "730111", "730201", "730202", "730203",
                "730204", "730205", "730206", "730207", "730208", "730209", "730210", "730301", "730302", "730303",
                "730304", "730305", "730306", "730307", "730308", "730401", "730402", "730403", "730404", "730405",
                "730406", "730407", "730408", "730409", "730410", "730411", "730501", "730502", "730503", "730504",
                "730505", "730506", "730507", "730508", "730509", "730601", "730602", "730603", "730604", "730605",
                "730606", "730607", "730608", "730609", "730610", "730611", "730612", "730613", "730614", "730615",
                "730616", "730617", "730618", "730701", "730702", "730703", "730704", "730705", "730706", "730707",
                "730708", "730709", "730801", "730802", "730803", "730804", "730805", "730806", "730807", "730808",
                "730809", "730810", "730811", "730812", "730813", "730814", "730815", "730816", "730817", "730818",
                "730819", "730820", "730821", "730822", "730823", "730824", "730825", "730826", "730827", "730901",
                "730902", "730903", "730904", "730905", "730906", "730907", "730908", "730909", "730910", "730911",
                "730912", "730913", "730914", "731001", "731002", "731003", "731004", "731005", "731006", "731007",
                "731008", "731009", "731010", "731011", "731012", "731101", "731102", "731103", "731104", "731105",
                "731106", "731107", "731201", "731202", "731203", "731204", "731205", "731206", "731207", "731208",
                "731301", "731302", "731303", "731304", "731305", "731306", "731307", "731308", "731309", "731310",
                "731311", "731312", "731313", "731314", "731401", "731402", "731403", "731404", "731405", "731406",
                "731407", "731408", "731409", "731410", "731411", "731501", "731502", "731503", "731504", "731505",
                "731506", "731507", "731508", "731509", "731510", "731511", "731512", "731601", "731602", "731603",
                "731604", "731605", "731606", "731607", "731608", "731609", "731610", "731611", "731612", "731701",
                "731702", "731703", "731704", "731705", "731706", "731707", "731708", "731709", "731710", "731711",
                "731712", "731713", "731714", "731715", "731716", "731717", "731718", "731719", "731720", "731721",
                "731722", "731801", "731802", "731803", "731805", "731809", "731811", "731812", "731813", "731819",
                "731820", "731827", "731828", "731829", "731831", "731833", "731834", "731835", "731837", "731838",
                "732201", "732202", "732203", "732204", "732205", "732206", "732207", "732208", "732209", "732210",
                "732211", "732212", "732401", "732402", "732403", "732404", "732405", "732406", "732407", "732408",
                "732409", "732410", "732411", "732601", "732602", "732603", "732604", "732605", "732606", "732607",
                "732608", "732609", "732610", "732611", "732612", "732613", "732614", "732615", "732616", "732617",
                "732618", "732619", "732620", "732621", "737101", "737102", "737103", "737104", "737105", "737106",
                "737107", "737108", "737109", "737110", "737111", "737112", "737113", "737114", "737201", "737202",
                "737203", "737204", "737301", "737302", "737303", "737304", "737305", "737306", "737307", "737308",
                "737309", "740101", "740104", "740107", "740108", "740110", "740112", "740114", "740118", "740120",
                "740124", "740125", "740127", "740201", "740202", "740203", "740204", "740205", "740210", "740211",
                "740215", "740216", "740217", "740218", "740219", "740220", "740221", "740223", "740224", "740225",
                "740228", "740231", "740232", "740233", "740236", "740237", "740306", "740307", "740313", "740314",
                "740315", "740316", "740317", "740318", "740319", "740320", "740323", "740324", "740325", "740326",
                "740327", "740328", "740330", "740331", "740332", "740333", "740334", "740337", "740411", "740422",
                "740423", "740424", "740427", "740428", "740429", "740501", "740502", "740503", "740504", "740505",
                "740506", "740507", "740508", "740509", "740510", "740511", "740512", "740513", "740514", "740515",
                "740516", "740517", "740518", "740519", "740520", "740521", "740522", "740601", "740602", "740603",
                "740604", "740605", "740606", "740607", "740608", "740609", "740610", "740611", "740612", "740613",
                "740614", "740615", "740616", "740617", "740618", "740619", "740620", "740621", "740622", "740701",
                "740702", "740703", "740704", "740705", "740706", "740707", "740708", "740801", "740802", "740803",
                "740804", "740805", "740806", "740807", "740808", "740809", "740810", "740811", "740812", "740813",
                "740814", "740815", "740901", "740902", "740903", "740904", "740905", "740906", "740907", "740908",
                "740909", "740910", "741001", "741002", "741003", "741004", "741005", "741006", "741101", "741102",
                "741103", "741104", "741105", "741106", "741107", "741108", "741109", "741110", "741111", "741201",
                "741202", "741203", "741204", "741205", "741206", "741207", "741301", "741302", "741303", "741304",
                "741305", "741306", "741307", "741308", "741309", "741310", "741311", "741401", "741402", "741403",
                "741404", "741405", "741406", "741407", "741501", "741502", "741503", "741504", "741505", "741506",
                "741507", "747101", "747102", "747103", "747104", "747105", "747106", "747107", "747108", "747109",
                "747110", "747201", "747202", "747203", "747204", "747205", "747206", "747207", "747208", "750101",
                "750102", "750103", "750104", "750105", "750109", "750110", "750111", "750113", "750114", "750116",
                "750117", "750118", "750119", "750120", "750121", "750122", "750123", "750124", "750201", "750202",
                "750203", "750204", "750205", "750206", "750207", "750301", "750302", "750303", "750304", "750305",
                "750306", "750307", "750308", "750309", "750310", "750311", "750312", "750313", "750314", "750315",
                "750316", "750317", "750318", "750401", "750402", "750403", "750404", "750405", "750406", "750407",
                "750408", "750409", "750410", "750411", "750412", "750413", "750501", "750502", "750503", "750504",
                "750505", "750506", "750507", "750508", "750509", "750510", "750511", "757101", "757102", "757103",
                "757104", "757105", "757106", "757107", "757108", "757109", "760101", "760102", "760103", "760104",
                "760105", "760106", "760107", "760108", "760109", "760110", "760111", "760112", "760201", "760202",
                "760203", "760204", "760207", "760208", "760211", "760212", "760213", "760215", "760216", "760301",
                "760302", "760303", "760304", "760305", "760306", "760307", "760308", "760309", "760310", "760311",
                "760312", "760313", "760314", "760315", "760316", "760317", "760401", "760402", "760403", "760404",
                "760405", "760406", "760407", "760408", "760409", "760410", "760411", "760412", "760413", "760414",
                "760415", "760416", "760501", "760502", "760503", "760504", "760505", "760506", "760507", "760508",
                "760601", "760602", "760603", "760604", "760605", "810101", "810102", "810106", "810109", "810111",
                "810112", "810113", "810114", "810115", "810116", "810117", "810120", "810121", "810122", "810123",
                "810124", "810125", "810126", "810201", "810203", "810204", "810205", "810213", "810214", "810215",
                "810216", "810217", "810218", "810219", "810301", "810302", "810303", "810304", "810305", "810306",
                "810307", "810308", "810309", "810318", "810401", "810402", "810403", "810406", "810410", "810411",
                "810412", "810413", "810414", "810415", "810501", "810502", "810503", "810504", "810505", "810506",
                "810507", "810508", "810509", "810510", "810511", "810512", "810513", "810514", "810515", "810601",
                "810602", "810603", "810604", "810605", "810606", "810607", "810608", "810609", "810610", "810611",
                "810701", "810702", "810703", "810704", "810705", "810706", "810707", "810708", "810709", "810710",
                "810801", "810802", "810803", "810804", "810805", "810806", "810807", "810808", "810809", "810810",
                "810811", "810812", "810813", "810814", "810815", "810816", "810817", "810901", "810902", "810903",
                "810904", "810905", "810906", "817101", "817102", "817103", "817104", "817105", "817201", "817202",
                "817203", "817204", "817205", "820101", "820102", "820103", "820104", "820105", "820107", "820108",
                "820109", "820201", "820202", "820203", "820204", "820205", "820206", "820207", "820208", "820304",
                "820305", "820306", "820307", "820308", "820309", "820310", "820311", "820312", "820313", "820314",
                "820315", "820316", "820319", "820320", "820321", "820322", "820401", "820402", "820403", "820404",
                "820405", "820406", "820407", "820408", "820409", "820410", "820411", "820412", "820413", "820414",
                "820415", "820416", "820417", "820418", "820419", "820420", "820421", "820422", "820423", "820424",
                "820425", "820426", "820427", "820428", "820429", "820430", "820501", "820502", "820503", "820506",
                "820507", "820508", "820509", "820510", "820511", "820512", "820513", "820518", "820601", "820602",
                "820603", "820604", "820605", "820606", "820607", "820608", "820609", "820610", "820701", "820702",
                "820703", "820704", "820705", "820801", "820802", "820803", "820804", "820805", "820806", "820807",
                "820808", "827101", "827102", "827103", "827104", "827105", "827106", "827107", "827201", "827202",
                "827203", "827204", "827205", "827206", "827207", "827208", "910101", "910102", "910103", "910104",
                "910105", "910106", "910107", "910108", "910109", "910110", "910111", "910112", "910113", "910114",
                "910115", "910116", "910117", "910118", "910119", "910120", "910201", "910203", "910204", "910212",
                "910215", "910225", "910227", "910228", "910229", "910234", "910235", "910240", "910241", "910242",
                "910243", "910244", "910245", "910246", "910247", "910248", "910249", "910250", "910251", "910252",
                "910253", "910254", "910255", "910256", "910257", "910258", "910259", "910260", "910261", "910262",
                "910263", "910264", "910265", "910266", "910267", "910268", "910301", "910302", "910303", "910304",
                "910305", "910306", "910307", "910308", "910309", "910310", "910311", "910312", "910313", "910314",
                "910315", "910316", "910317", "910318", "910319", "910401", "910402", "910403", "910406", "910407",
                "910410", "910411", "910412", "910416", "910417", "910421", "910422", "910423", "910424", "910425",
                "910501", "910502", "910503", "910504", "910505", "910506", "910507", "910508", "910509", "910510",
                "910511", "910512", "910513", "910514", "910601", "910602", "910603", "910604", "910605", "910608",
                "910609", "910610", "910611", "910612", "910613", "910614", "910615", "910616", "910617", "910618",
                "910619", "910620", "910621", "910701", "910703", "910706", "910707", "910708", "910710", "910711",
                "910712", "910717", "910718", "910719", "910720", "910721", "910722", "910723", "910724", "910725",
                "910726", "910727", "910728", "910729", "910730", "910731", "910732", "910733", "910734", "910801",
                "910802", "910804", "910807", "910809", "910812", "910813", "910819", "910820", "910821", "910901",
                "910902", "910903", "910904", "910905", "910906", "910907", "910908", "910909", "910910", "910911",
                "910912", "910913", "910914", "910916", "910917", "910918", "911001", "911002", "911003", "911004",
                "911005", "911009", "911012", "911013", "911014", "911015", "911101", "911102", "911103", "911104",
                "911105", "911106", "911107", "911201", "911202", "911203", "911204", "911205", "911206", "911207",
                "911208", "911209", "911210", "911211", "911212", "911213", "911214", "911215", "911216", "911217",
                "911218", "911219", "911220", "911221", "911222", "911223", "911224", "911225", "911226", "911227",
                "911228", "911229", "911230", "911231", "911232", "911233", "911234", "911301", "911302", "911303",
                "911306", "911307", "911308", "911309", "911310", "911311", "911312", "911313", "911314", "911315",
                "911316", "911317", "911318", "911319", "911320", "911321", "911322", "911323", "911324", "911325",
                "911326", "911327", "911328", "911329", "911330", "911331", "911332", "911333", "911334", "911335",
                "911336", "911337", "911338", "911339", "911340", "911341", "911342", "911343", "911344", "911345",
                "911346", "911347", "911348", "911349", "911350", "911351", "911352", "911353", "911401", "911402",
                "911403", "911404", "911405", "911406", "911407", "911408", "911409", "911410", "911411", "911412",
                "911413", "911414", "911415", "911416", "911418", "911419", "911420", "911421", "911422", "911423",
                "911424", "911425", "911426", "911427", "911428", "911429", "911430", "911431", "911432", "911433",
                "911434", "911435", "911436", "911437", "911438", "911439", "911440", "911441", "911442", "911443",
                "911444", "911445", "911446", "911447", "911501", "911503", "911507", "911508", "911509", "911510",
                "911514", "911515", "911601", "911602", "911603", "911604", "911605", "911606", "911607", "911608",
                "911609", "911610", "911611", "911612", "911613", "911614", "911615", "911616", "911617", "911618",
                "911619", "911620", "911701", "911702", "911703", "911704", "911705", "911706", "911707", "911708",
                "911709", "911710", "911711", "911712", "911713", "911714", "911715", "911801", "911802", "911803",
                "911804", "911805", "911806", "911807", "911808", "911809", "911810", "911811", "911812", "911813",
                "911814", "911815", "911816", "911817", "911818", "911819", "911901", "911902", "911903", "911904",
                "911905", "912001", "912002", "912003", "912004", "912005", "912006", "912007", "912008", "912101",
                "912102", "912103", "912104", "912105", "912201", "912202", "912203", "912204", "912205", "912301",
                "912302", "912303", "912304", "912305", "912306", "912307", "912308", "912309", "912310", "912311",
                "912312", "912313", "912314", "912315", "912316", "912317", "912318", "912319", "912320", "912321",
                "912322", "912323", "912324", "912325", "912326", "912327", "912328", "912329", "912330", "912331",
                "912332", "912333", "912334", "912335", "912336", "912337", "912338", "912339", "912401", "912402",
                "912403", "912404", "912405", "912406", "912407", "912408", "912409", "912410", "912411", "912412",
                "912413", "912414", "912415", "912416", "912417", "912418", "912419", "912420", "912421", "912422",
                "912423", "912424", "912425", "912426", "912427", "912428", "912429", "912430", "912431", "912432",
                "912501", "912502", "912503", "912504", "912505", "912506", "912507", "912508", "912601", "912602",
                "912603", "912604", "912605", "912606", "912607", "912608", "912609", "912610", "912701", "912702",
                "912703", "912704", "912705", "912706", "912707", "912708", "912801", "912802", "912803", "912804",
                "912805", "917101", "917102", "917103", "917104", "917105", "920101", "920104", "920105", "920106",
                "920107", "920108", "920110", "920112", "920113", "920114", "920117", "920118", "920120", "920139",
                "920140", "920141", "920142", "920203", "920204", "920205", "920212", "920213", "920214", "920215",
                "920217", "920221", "920301", "920302", "920303", "920304", "920305", "920306", "920307", "920308",
                "920309", "920310", "920311", "920312", "920313", "920314", "920315", "920316", "920317", "920401",
                "920404", "920406", "920409", "920410", "920411", "920412", "920414", "920415", "920420", "920421",
                "920422", "920424", "920501", "920502", "920503", "920504", "920505", "920506", "920507", "920508",
                "920509", "920510", "920511", "920513", "920514", "920515", "920516", "920517", "920518", "920519",
                "920520", "920521", "920522", "920523", "920524", "920525", "920601", "920602", "920603", "920604",
                "920605", "920606", "920607", "920608", "920609", "920610", "920611", "920612", "920613", "920614",
                "920615", "920616", "920617", "920618", "920619", "920620", "920621", "920622", "920623", "920624",
                "920701", "920702", "920703", "920704", "920705", "920706", "920707", "920708", "920709", "920710",
                "920711", "920712", "920713", "920801", "920802", "920803", "920804", "920805", "920806", "920807",
                "920901", "920902", "920903", "920904", "920905", "920906", "920907", "920913", "920914", "920916",
                "920917", "920918", "920919", "920920", "920921", "920922", "920923", "920924", "920925", "920926",
                "920927", "920928", "920929", "921001", "921002", "921003", "921004", "921005", "921006", "921007",
                "921008", "921009", "921010", "921011", "921101", "921102", "921103", "921104", "921105", "921106",
                "921201", "921202", "921203", "921204", "921205", "921206", "921207", "921208", "921209", "921210",
                "927101", "927102", "927103", "927104", "927105", "927106", "927107", "927108", "927109", "927110"]
    """The district list for IDN"""


NationalID = NIK
"""alias of NIK"""
